@@ -25,8 +25,8 @@
  * 桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.14 $
- * $Date: 2012/09/19 03:22:42 $
+ * $Revision: 1.15 $
+ * $Date: 2013/07/23 06:45:20 $
  *
  **********************************************************/
 
@@ -84,8 +84,7 @@ if (isset($_POST["login"]) === TRUE) {
 
     /* 桼̾Υå */
     if ($_POST["user"] != "" &&
-        check_search_name($_POST["user"]) === TRUE &&
-        check_passwd($_POST["passwd"], MINPASSWD, MAXPASSWD) === TRUE) {
+        check_search_name($_POST["user"]) === TRUE) {
         /* åå& */
         $chk_mode = GENUSER;
 
